Pyjamas is an independent free software project that is used by people who prefer to actually get on with the job of writing apps, rather than glorying or revelling in the frustration of "traditional" web development. Hitting your head against a wall continuously every day doesn't hurt any more when you stop doing it, and much of "traditional" web development - of dealing with all the browser incompatibilities at a low level - can be considered to be the same as brick-wall-nutting.

In other words, you're here gaining the benefit of the experience of people who have spent quite some time searching out - and then improving - the Pyjamas Technology, to make their own lives easier. If there's an area which isn't clearly documented, you might like to consider funding them to tell you about it.

That having been said, there is actually one heck of a lot of documentation: see the main Pyjamas site for links to the tutorials, the Pyjamas Book, the API reference guides, the Showcase example which includes source code examples for each type of Widget and Panel (that can be cut/pasted into your app), and much more. If that wasn't enough, the GWT User-Interface modules on which the Pyjamas UI modules are based are so similar that even the GWT documentation is still relevant and useful.